@@ -125,7 +125,6 @@ void DavCollectionModifyJob::davJobFinished(KJob *job)
     QDomElement responseElement = Utils::firstChildElementNS(response.documentElement(), QStringLiteral("DAV:"), QStringLiteral("response"));
 
     bool hasError = false;
-    QString errorText;
 
     // parse all propstats answers to get the eventual errors
     const QDomNodeList propstats = responseElement.elementsByTagNameNS(QStringLiteral("DAV:"), QStringLiteral("propstat"));
@@ -134,7 +133,7 @@ void DavCollectionModifyJob::davJobFinished(KJob *job)
         const QDomElement statusElement = Utils::firstChildElementNS(propstatElement, QStringLiteral("DAV:"), QStringLiteral("status"));
 
         const QString statusText = statusElement.text();
-        if (statusText.contains(QStringLiteral("200"))) {
+        if (statusText.contains(QLatin1String("200"))) {
             continue;
         } else {
             // Generic error
